==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/CalloutAnnotation_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DependencyObject } from "igniteui-react-core";
import { INotifyPropertyChanged_$type, Base, PropertyChangedEventArgs, typeCast, markType, markDep } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Series } from "./Series";
import { Brush } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
/**
 * @hidden
 */
export let CalloutAnnotation = /*@__PURE__*/ (() => {
    class CalloutAnnotation extends DependencyObject {
        constructor() {
            super(...arguments);
            this.propertyChanged = null;
            this.k = null;
            this.ab = 0;
            this.ac = 0;
            this.am = null;
            this.aw = null;
            this.aa = null;
            this.z = null;
            this.l = null;
            this._formatLabel = null;
            this.bk = null;
            this.bh = null;
            this.bj = null;
            this.bi = null;
            this.x = 0;
            this.o = false;
            this.n = true;
            this.bo = null;
            this.u = NaN;
            this.w = NaN;
            this.v = NaN;
            this.t = NaN;
        }
        a0(a, b, c) {
            this.az(a, b, c);
            if (this.propertyChanged != null) {
                this.propertyChanged(this, new PropertyChangedEventArgs(a));
            }
        }
        az(a, b, c) {
            switch (a) {
                case CalloutAnnotation.$$p[13]:
                    this.ab = c;
                    break;
                case CalloutAnnotation.$$p[14]:
                    this.ac = c;
                    break;
                case CalloutAnnotation.$$p[9]:
                    this.l = c;
                    break;
                case CalloutAnnotation.$$p[5]:
                    this.z = c;
                    break;
                case CalloutAnnotation.$$p[6]:
                    this.aa = c;
                    break;
                case CalloutAnnotation.$$p[12]:
                    this.am = c;
                    break;
                case CalloutAnnotation.$$p[11]:
                    this.bk = c;
                    break;
                case CalloutAnnotation.$$p[7]:
                    this.bi = c;
                    break;
                case CalloutAnnotation.$$p[8]:
                    this.bj = c;
                    break;
                case CalloutAnnotation.$$p[4]:
                    this.bh = c;
                    break;
                case CalloutAnnotation.$$p[10]:
                    this.x = c;
                    break;
                case CalloutAnnotation.$$p[1]:
                    this.n = true;
                    this.u = c;
                    break;
                case CalloutAnnotation.$$p[3]:
                    this.n = true;
                    this.w = c;
                    break;
                case CalloutAnnotation.$$p[2]:
                    this.n = true;
                    this.v = c;
                    break;
                case CalloutAnnotation.$$p[0]:
                    this.n = true;
                    this.t = c;
                    break;
            }
            this.o = true;
        }
        get formatLabel() {
            return this._formatLabel;
        }
        set formatLabel(a) {
            this._formatLabel = a;
        }
        get backgroundPadding() {
            if (this.n) {
                this.n = false;
                this.bo = new Thickness(1, this.u, this.w, this.v, this.t);
            }
            return this.bo;
        }
        set backgroundPadding(a) {
            this.backgroundPaddingLeft = a.c;
            this.backgroundPaddingTop = a.e;
            this.backgroundPaddingRight = a.d;
            this.backgroundPaddingBottom = a.b;
        }
    }
    CalloutAnnotation.$t = /*@__PURE__*/ markType(CalloutAnnotation, 'CalloutAnnotation', DependencyObject.$, [INotifyPropertyChanged_$type]);
    CalloutAnnotation.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, CalloutAnnotation, 'a0', ['BackgroundPaddingBottom', [1, NaN], 'BackgroundPaddingLeft', [1, NaN], 'BackgroundPaddingRight', [1, NaN], 'BackgroundPaddingTop', [1, NaN], 'Background', [Brush.$, null], 'Content', [4, null], 'Key', [4, null], 'LeaderBrush', [Brush.$, null], 'Outline', [Brush.$, null], 'Series', [Series.$, null], 'StrokeThickness', [1, 0], 'TextColor', [Brush.$, null], 'Text', [2, null], 'XValue', [4, 0], 'YValue', [4, 0]]);
    return CalloutAnnotation;
})();
/**
 * @hidden
 */
export let CalloutAnnotationWrapper = /*@__PURE__*/ (() => {
    class CalloutAnnotationWrapper extends Base {
        constructor() {
            super(...arguments);
            this.a = null;
            this.c = null;
        }
        get b() {
            return this.a;
        }
        set b(a) {
            this.a = a;
            this.a.k = this;
        }
        equals(a) {
            let b = typeCast(CalloutAnnotationWrapper.$, a);
            if (b == null) {
                return super.equals(a);
            }
            if (b.b == null && this.b == null) {
                return super.equals(a);
            }
            if (b.b == null) {
                return false;
            }
            if (this.b.aa != null || b.b.aa != null) {
                return Base.equalsStatic(this.b.aa, b.b.aa);
            }
            return super.equals(a);
        }
        getHashCode() {
            if (this.b == null || this.b.aa == null) {
                return super.getHashCode();
            }
            return Base.getHashCodeStatic(this.b.aa);
        }
    }
    CalloutAnnotationWrapper.$t = /*@__PURE__*/ markType(CalloutAnnotationWrapper, 'CalloutAnnotationWrapper');
    return CalloutAnnotationWrapper;
})();

==> igniteui-react-charts-18.2.0.tgz: package/esm2015/lib/CalloutAnnotation_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DependencyObject } from "igniteui-react-core";
import { INotifyPropertyChanged_$type, Base, PropertyChangedEventArgs, typeCast, markType, markDep } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { Series } from "./Series";
import { Brush } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
/**
 * @hidden
 */
export let CalloutAnnotation = /*@__PURE__*/ (() => {
    class CalloutAnnotation extends DependencyObject {
        constructor() {
            super(...arguments);
            this.propertyChanged = null;
            this.k = null;
            this.ac = 0;
            this.ad = 0;
            this.ao = null;
            this.ay = null;
            this.ab = null;
            this.aa = null;
            this.l = null;
            this._formatLabel = null;
            this.bn = null;
            this.bk = null;
            this.bm = null;
            this.bl = null;
            this.y = 0;
            this.o = false;
            this.n = true;
            this.br = null;
            this.v = NaN;
            this.x = NaN;
            this.w = NaN;
            this.u = NaN;
        }
        a2(a, b, c) {
            this.a1(a, b, c);
            if (this.propertyChanged != null) {
                this.propertyChanged(this, new PropertyChangedEventArgs(a));
            }
        }
        a1(a, b, c) {
            switch (a) {
                case CalloutAnnotation.$$p[14]:
                    this.ac = c;
                    break;
                case CalloutAnnotation.$$p[15]:
                    this.ad = c;
                    break;
                case CalloutAnnotation.$$p[10]:
                    this.l = c;
                    break;
                case CalloutAnnotation.$$p[6]:
                    this.aa = c;
                    break;
                case CalloutAnnotation.$$p[7]:
                    this.ab = c;
                    break;
                case CalloutAnnotation.$$p[13]:
                    this.ao = c;
                    break;
                case CalloutAnnotation.$$p[12]:
                    this.bn = c;
                    break;
                case CalloutAnnotation.$$p[8]:
                    this.bl = c;
                    break;
                case CalloutAnnotation.$$p[9]:
                    this.bm = c;
                    break;
                case CalloutAnnotation.$$p[5]:
                    this.bk = c;
                    break;
                case CalloutAnnotation.$$p[11]:
                    this.y = c;
                    break;
                case CalloutAnnotation.$$p[2]:
                    this.n = true;
                    this.v = c;
                    break;
                case CalloutAnnotation.$$p[4]:
                    this.n = true;
                    this.x = c;
                    break;
                case CalloutAnnotation.$$p[3]:
                    this.n = true;
                    this.w = c;
                    break;
                case CalloutAnnotation.$$p[1]:
                    this.n = true;
                    this.u = c;
                    break;
            }
            this.o = true;
        }
        get formatLabel() {
            return this._formatLabel;
        }
        set formatLabel(a) {
            this._formatLabel = a;
        }
        get backgroundPadding() {
            if (this.n) {
                this.n = false;
                this.br = new Thickness(1, this.v, this.x, this.w, this.u);
            }
            return this.br;
        }
        set backgroundPadding(a) {
            this.backgroundPaddingLeft = a.left;
            this.backgroundPaddingTop = a.top;
            this.backgroundPaddingRight = a.right;
            this.backgroundPaddingBottom = a.bottom;
        }
    }
    CalloutAnnotation.$t = /*@__PURE__*/ markType(CalloutAnnotation, 'CalloutAnnotation', DependencyObject.$, [INotifyPropertyChanged_$type]);
    CalloutAnnotation.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, CalloutAnnotation, 'a2', ['BackgroundCornerRadius', [1, NaN], 'BackgroundPaddingBottom', [1, NaN], 'BackgroundPaddingLeft', [1, NaN], 'BackgroundPaddingRight', [1, NaN], 'BackgroundPaddingTop', [1, NaN], 'Background', [Brush.$, null], 'Content', [4, null], 'Key', [4, null], 'LeaderBrush', [Brush.$, null], 'Outline', [Brush.$, null], 'Series', [Series.$, null], 'StrokeThickness', [1, 0], 'TextColor', [Brush.$, null], 'Text', [2, null], 'XValue', [4, 0], 'YValue', [4, 0]]);
    return CalloutAnnotation;
})();
/**
 * @hidden
 */
export let CalloutAnnotationWrapper = /*@__PURE__*/ (() => {
    class CalloutAnnotationWrapper extends Base {
        constructor() {
            super(...arguments);
            this.a = null;
            this.c = null;
            this.e = 0;
            this.f = 0;
        }
        get b() {
            return this.a;
        }
        set b(a) {
            this.a = a;
            this.a.k = this;
        }
        equals(a) {
            let b = typeCast(CalloutAnnotationWrapper.$, a);
            if (b == null) {
                return super.equals(a);
            }
            if (b.b == null && this.b == null) {
                return super.equals(a);
            }
            if (b.b == null) {
                return false;
            }
            if (this.b.ab != null || b.b.ab != null) {
                return Base.equalsStatic(this.b.ab, b.b.ab);
            }
            return super.equals(a);
        }
        getHashCode() {
            if (this.b == null || this.b.ab == null) {
                return super.getHashCode();
            }
            return Base.getHashCodeStatic(this.b.ab);
        }
    }
    CalloutAnnotationWrapper.$t = /*@__PURE__*/ markType(CalloutAnnotationWrapper, 'CalloutAnnotationWrapper');
    return CalloutAnnotationWrapper;
})();
